#!/usr/bin/env bash
# set -euo pipefail

streamds -h

streamds list

streamds get detectors

streamds help detectors

streamds help foo
